#include "FaxAPI.h"

static Err CallFaxApp(char *textToSend)
{
	Err		err;
	UInt16	cardNo;
	LocalID	dbID;
	char	ln[64];
	MemPtr	cmdPtr = NULL;
	DmSearchStateType		searchState;
	faxAppCmdSendFaxType	*faxCmd;


	// Allocate block for the command pointer
	cmdPtr = MemPtrNew(sizeof(faxAppCmdSendFaxType) + StrLen(textToSend));
	if (!cmdPtr) {
		err = memErrNotEnoughSpace;
		GenericOKAlert("Unable to allocate buffer.");
		goto out;
	}
	
	// Must set owner to system, otherwise it is gone when we exit the app!
	err = MemPtrSetOwner(cmdPtr, 0);
	if (err) {
		GenericOKAlert("Unable to set buffer owner.");
		goto out;
	}
	
	// init the command pointer
	MemSet(cmdPtr, MemPtrSize(cmdPtr), 0);
	faxCmd = (faxAppCmdSendFaxType *)cmdPtr;
	faxCmd->cookie = faxAppCmdSendFaxCookie;
	faxCmd->version = faxAppCmdSendFaxVersion;
	faxCmd->callingCreatorID = palmPageType;	// Your app creator ID here
	faxCmd->previewFirst = false;	// true to preview first
	StrCopy(faxCmd->dialName, "Test Fax");
	StrCopy(faxCmd->dialNumber, "555-1212");
	StrCopy(faxCmd->text, textToSend);
	
	// Find the app
	err = DmGetNextDatabaseByTypeCreator(
		true, &searchState, 
		sysFileTApplication, faxAppCreatorID, true, &cardNo, &dbID);
	if (err) {
		StrPrintF(ln, "Error %d finding fax app.", err);
		GenericOKAlert(ln);
		goto out;
	}
	
	// Call the app
	err = SysUIAppSwitch(cardNo, dbID, faxAppCmdSendFax, cmdPtr);
	if (err) {
		StrPrintF(ln, "Error %d calling fax app.", err);
		GenericOKAlert(ln);
		goto out;
	}

	// No error! We will be switching to other app,
	// So clear cmdPtr so we don't free it ourselves
	cmdPtr = NULL;

out:
	// If we got an error (meaning unable to switch), we'll need to free the memory
	if (cmdPtr) MemPtrFree(cmdPtr);
	
	return err;
}
